package com.sky.controller.admin;

import com.sky.dto.EmployeeLoginDTO;
import com.sky.entity.Employee;
import com.sky.entity.TLandimg;
import com.sky.properties.JwtProperties;
import com.sky.result.Result;
import com.sky.service.EmployeeService;
import com.sky.utils.AliOssUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.util.List;
import java.util.UUID;
/**
 * @Author zhangyifan
 * @Date 2024/4/11 15:12
 */

/**
 * 员工管理
 */
@RestController
@RequestMapping("/admin/employee")
@Slf4j
public class EmployeeController {
    public String FilePath;

    @Autowired
    private EmployeeService employeeService;
    @Autowired
    private JwtProperties jwtProperties;
    @Autowired
    private AliOssUtil aliOssUtil;


    /**
     * 根据当前位置经纬度获取距离最近的三个位置
     *
     * @param volatitude
     * @param volongitude
     * @return
     */
    @GetMapping("/location")
    public Result<List<Employee>> getlocation(@RequestParam double volatitude, @RequestParam double volongitude) {

        return Result.success(employeeService.getlocation(volatitude, volongitude));

    }

//    /**
//     * 上传表单信息
//     *
//     * @return
//     */
//    @PostMapping("/getLandImg")
//    public Result<String> getLandImg(@RequestBody TLandimg landimg) {
//        System.out.println("这是site: " + landimg.getSite() + " author: " + landimg.getAuthor());
//        employeeService.postform(landimg.getAuthor(), landimg.getSite(), landimg.getPzdt(), landimg.getImgurl());
//        return Result.success();
//    }


    /**
     * 把拍照的图片上传到服务器 然后把url地址返回
     * @param photo
     * @return
     * @throws IOException
     */
    @PostMapping("/geturl")
    public Result uploadPhoto(@RequestParam("photo") MultipartFile photo) throws IOException {
//        System.out.println("photo" + photo);
        try {
            String originalFilename = photo.getOriginalFilename();
            String extension = originalFilename.substring(originalFilename.lastIndexOf("."));
            String objectName = UUID.randomUUID().toString() + extension;
            String fileUrl = aliOssUtil.upload(photo.getBytes(), objectName);
            String FileVO = "https://aielab-zht.oss-cn-shanghai.aliyuncs.com/"+objectName;
            FilePath = fileUrl;
            System.out.println("这是fileurl" + fileUrl);
            return Result.success(FileVO);
        } catch (IOException e) {
            log.error("上传失败");
        }
        return null;
    }

    /**
     * 登录
     *
     * @param employeeLoginDTO
     * @return
     */
    @PostMapping("/login")
    public Result login(@RequestBody EmployeeLoginDTO employeeLoginDTO) {
        log.info("员工登录：{}", employeeLoginDTO);

        Employee employee = employeeService.login(employeeLoginDTO);

        //登录成功后，生成jwt令牌
        /*Map<String, Object> claims = new HashMap<>();
        claims.put(JwtClaimsConstant.EMP_ID, employee.getId());
        String token = JwtUtil.createJWT(
                jwtProperties.getAdminSecretKey(),
                jwtProperties.getAdminTtl(),
                claims);

        EmployeeLoginVO employeeLoginVO = EmployeeLoginVO.builder()
                .id(employee.getId())
                .userName(employee.getUsername())
                .name(employee.getName())
                .token(token)
                .build();*/

        return Result.success(employee);
    }

    /**
     * 退出
     *
     * @return
     */
    @PostMapping("/logout")
    public Result<String> logout() {
        return Result.success();
    }

}
